@@ -41,7 +41,7 @@ class KnowledgeBase:
         url = BASE_URL + f'knowledge_bases/{self.kb_id}/documents'
         resp = _format_http_response(requests.get(url, headers=get_headers()))
         documents = {}
-        for document in resp['body']:
+        for document in resp['body']['documents']:
             kb_document = KnowledgeBaseDocument(
                 kb_id=document['id'],
                 content=None,
@@ -114,7 +114,7 @@ def get_knowledge_bases():
     url = BASE_URL + 'knowledge_bases'
     resp = requests.get(url, headers=get_headers())
     resp = _format_http_response(resp)
-    for knowledge_base in resp['body']:
+    for knowledge_base in resp['body']['knowledge_bases']:
         kb = KnowledgeBase(
             title=knowledge_base['title'],
             kb_id=knowledge_base['id'],
